Package: wiggleplotr
Title: Make read coverage plots from BigWig files
Version: 1.37.0
Authors@R: person("Kaur", "Alasoo", 
                  email = "kaur.alasoo@gmail.com", 
                  role = c("aut", "cre"))
Description: Tools to visualise read coverage from sequencing
        experiments together with genomic annotations (genes,
        transcripts, peaks). Introns of long transcripts can be
        rescaled to a fixed length for better visualisation of exonic
        read coverage.
Depends: R (>= 3.6)
Imports: dplyr, ggplot2 (>= 2.2.0), GenomicRanges, rtracklayer,
        cowplot, assertthat, purrr, S4Vectors, IRanges, GenomeInfoDb
License: Apache License 2.0
LazyData: true
RoxygenNote: 7.2.0
Encoding: UTF-8
Suggests: knitr, rmarkdown, biomaRt, GenomicFeatures, testthat,
        ensembldb, EnsDb.Hsapiens.v86, org.Hs.eg.db,
        TxDb.Hsapiens.UCSC.hg38.knownGene, AnnotationDbi,
        AnnotationFilter, arrow
VignetteBuilder: knitr
biocViews: ImmunoOncology, Coverage, RNASeq, ChIPSeq, Sequencing,
        Visualization, GeneExpression, Transcription,
        AlternativeSplicing
git_url: https://git.bioconductor.org/packages/wiggleplotr
git_branch: devel
git_last_commit: fc07c23
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 01:50:54 UTC; biocbuild
Author: Kaur Alasoo [aut, cre]
Maintainer: Kaur Alasoo <kaur.alasoo@gmail.com>
