# Generated by roxygen2: do not edit by hand

export(extractCoverageData)
export(getGenotypePalette)
export(makeManhattanPlot)
export(plotCoverage)
export(plotCoverageData)
export(plotCoverageFromEnsembldb)
export(plotCoverageFromUCSC)
export(plotTranscripts)
export(plotTranscriptsFromEnsembldb)
export(plotTranscriptsFromUCSC)
import(ggplot2)
importFrom(dplyr,"%>%")
importFrom(dplyr,"row_number")
